@@ -141,6 +141,19 @@
                      }
                      x
                    })
+  if (length(.w) > 0 && utils::packageVersion("rxode2") >= "4.0.0") {
+    .w  <- which(vapply(seq_along(.model),
+                        function(i) {
+                          identical(.model[[i]][[1]], quote(`<-`)) &&
+                            identical(.model[[i]][[2]], quote(`central`))
+                        }, logical(1), USE.NAMES=FALSE))
+    if (length(.w) > 0) {
+      .model <- lapply(seq_along(.model)[-.w],
+                       function(i) {
+                         .model[[i]]
+                       })
+    }
+  }
   .ini <- as.expression(lotri::as.lotri(.ret$iniDf))
   .ini[[1]] <- str2lang("ini")
   .model <- as.call(c(list(quote(`{`)), .model))
